@@ -1,7 +1,5 @@
 #include <libxfce4panel/libxfce4panel-marshal.h>
-
-#include	<glib-object.h>
-
+#include <glib-object.h>
 
 #ifdef G_ENABLE_DEBUG
 #define g_marshal_value_peek_boolean(v)  g_value_get_boolean (v)
@@ -49,22 +47,21 @@
 #define g_marshal_value_peek_variant(v)  (v)->data[0].v_pointer
 #endif /* !G_ENABLE_DEBUG */
 
-
 /* BOOLEAN:INT (libxfce4panel-marshal.list:1) */
 void
 _libxfce4panel_marshal_BOOLEAN__INT (GClosure     *closure,
-                                     GValue       *return_value G_GNUC_UNUSED,
+                                     GValue       *return_value,
                                      guint         n_param_values,
                                      const GValue *param_values,
                                      gpointer      invocation_hint G_GNUC_UNUSED,
                                      gpointer      marshal_data)
 {
-  typedef gboolean (*GMarshalFunc_BOOLEAN__INT) (gpointer     data1,
-                                                 gint         arg_1,
-                                                 gpointer     data2);
-  GMarshalFunc_BOOLEAN__INT callback;
-  GCClosure *cc = (GCClosure*) closure;
+  typedef gboolean (*GMarshalFunc_BOOLEAN__INT) (gpointer data1,
+                                                 gint arg1,
+                                                 gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
   gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__INT callback;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -92,19 +89,19 @@ _libxfce4panel_marshal_BOOLEAN__INT (GClosure     *closure,
 /* BOOLEAN:STRING,BOXED (libxfce4panel-marshal.list:2) */
 void
 _libxfce4panel_marshal_BOOLEAN__STRING_BOXED (GClosure     *closure,
-                                              GValue       *return_value G_GNUC_UNUSED,
+                                              GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint G_GNUC_UNUSED,
                                               gpointer      marshal_data)
 {
-  typedef gboolean (*GMarshalFunc_BOOLEAN__STRING_BOXED) (gpointer     data1,
-                                                          gpointer     arg_1,
-                                                          gpointer     arg_2,
-                                                          gpointer     data2);
-  GMarshalFunc_BOOLEAN__STRING_BOXED callback;
-  GCClosure *cc = (GCClosure*) closure;
+  typedef gboolean (*GMarshalFunc_BOOLEAN__STRING_BOXED) (gpointer data1,
+                                                          gpointer arg1,
+                                                          gpointer arg2,
+                                                          gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
   gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__STRING_BOXED callback;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
