@@ -1,15 +1,15 @@
 /*
  * Copyright (C) 2008-2010 Nick Schermer <nick@xfce.org>
  *
- * This library is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by the Free
- * Software Foundation; either version 2 of the License, or (at your option)
- * any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
- * more details.
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
@@ -105,28 +105,46 @@ enum
 
 
 
-static void       xfce_panel_image_get_property  (GObject         *object,
-                                                  guint            prop_id,
-                                                  GValue          *value,
-                                                  GParamSpec      *pspec);
-static void       xfce_panel_image_set_property  (GObject         *object,
-                                                  guint            prop_id,
-                                                  const GValue    *value,
-                                                  GParamSpec      *pspec);
-static void       xfce_panel_image_finalize      (GObject         *object);
-static void       xfce_panel_image_size_request  (GtkWidget       *widget,
-                                                  GtkRequisition  *requisition);
-static void       xfce_panel_image_size_allocate (GtkWidget       *widget,
-                                                  GtkAllocation   *allocation);
-static gboolean   xfce_panel_image_expose_event  (GtkWidget       *widget,
-                                                  GdkEventExpose  *event);
-static void       xfce_panel_image_style_set     (GtkWidget       *widget,
-                                                  GtkStyle        *previous_style);
-static gboolean   xfce_panel_image_load          (gpointer         data);
-static void       xfce_panel_image_load_destroy  (gpointer         data);
-static GdkPixbuf *xfce_panel_image_scale_pixbuf  (GdkPixbuf       *source,
-                                                  gint             dest_width,
-                                                  gint             dest_height);
+static void       xfce_panel_image_get_property         (GObject         *object,
+                                                         guint            prop_id,
+                                                         GValue          *value,
+                                                         GParamSpec      *pspec);
+static void       xfce_panel_image_set_property         (GObject         *object,
+                                                         guint            prop_id,
+                                                         const GValue    *value,
+                                                         GParamSpec      *pspec);
+static void       xfce_panel_image_finalize             (GObject         *object);
+#if GTK_CHECK_VERSION (3, 0, 0)
+static void       xfce_panel_image_get_preferred_width  (GtkWidget       *widget,
+                                                         gint            *minimum_width,
+                                                         gint            *natural_width);
+static void       xfce_panel_image_get_preferred_height (GtkWidget       *widget,
+                                                         gint            *minimum_height,
+                                                         gint            *natural_height);
+#else
+static void       xfce_panel_image_size_request         (GtkWidget       *widget,
+                                                         GtkRequisition  *requisition);
+#endif
+static void       xfce_panel_image_size_allocate        (GtkWidget       *widget,
+                                                         GtkAllocation   *allocation);
+#if GTK_CHECK_VERSION (3, 0, 0)
+static gboolean   xfce_panel_image_draw                 (GtkWidget       *widget,
+                                                         cairo_t         *cr);
+#else
+static gboolean   xfce_panel_image_expose_event         (GtkWidget       *widget,
+                                                         GdkEventExpose  *event);
+#endif
+#if GTK_CHECK_VERSION (3, 0, 0)
+static void       xfce_panel_image_style_updated        (GtkWidget       *widget);
+#else
+static void       xfce_panel_image_style_set            (GtkWidget       *widget,
+                                                         GtkStyle        *previous_style);
+#endif
+static gboolean   xfce_panel_image_load                 (gpointer         data);
+static void       xfce_panel_image_load_destroy         (gpointer         data);
+static GdkPixbuf *xfce_panel_image_scale_pixbuf         (GdkPixbuf       *source,
+                                                         gint             dest_width,
+                                                         gint             dest_height);
 
 
 
@@ -143,15 +161,25 @@ xfce_panel_image_class_init (XfcePanelImageClass *klass)
   g_type_class_add_private (klass, sizeof (XfcePanelImagePrivate));
 
   gobject_class = G_OBJECT_CLASS (klass);
-  gobject_class->get_property = xfce_panel_image_get_property;
   gobject_class->set_property = xfce_panel_image_set_property;
+  gobject_class->get_property = xfce_panel_image_get_property;
   gobject_class->finalize = xfce_panel_image_finalize;
 
   gtkwidget_class = GTK_WIDGET_CLASS (klass);
+#if GTK_CHECK_VERSION (3, 0, 0)
+  gtkwidget_class->get_preferred_width = xfce_panel_image_get_preferred_width;
+  gtkwidget_class->get_preferred_height = xfce_panel_image_get_preferred_height;
+#else
   gtkwidget_class->size_request = xfce_panel_image_size_request;
+#endif
   gtkwidget_class->size_allocate = xfce_panel_image_size_allocate;
+#if GTK_CHECK_VERSION (3, 0, 0)
+  gtkwidget_class->draw = xfce_panel_image_draw;
+  gtkwidget_class->style_updated = xfce_panel_image_style_updated;
+#else
   gtkwidget_class->expose_event = xfce_panel_image_expose_event;
   gtkwidget_class->style_set = xfce_panel_image_style_set;
+#endif
 
   g_object_class_install_property (gobject_class,
                                    PROP_SOURCE,
@@ -194,7 +222,7 @@ xfce_panel_image_class_init (XfcePanelImageClass *klass)
 static void
 xfce_panel_image_init (XfcePanelImage *image)
 {
-  GTK_WIDGET_SET_FLAGS (image, GTK_NO_WINDOW);
+  gtk_widget_set_has_window (GTK_WIDGET (image), FALSE);
 
   image->priv = G_TYPE_INSTANCE_GET_PRIVATE (image, XFCE_TYPE_PANEL_IMAGE, XfcePanelImagePrivate);
 
@@ -280,6 +308,127 @@ xfce_panel_image_finalize (GObject *object)
 
 
 
+//#if GTK_CHECK_VERSION (3, 0, 0) && !GTK_CHECK_VERSION (3, 10, 0)
+#if GTK_CHECK_VERSION (3, 0, 0)
+#define GTK_BUTTON_SIZING_FIX
+#endif
+
+#ifdef GTK_BUTTON_SIZING_FIX
+/* When can_focus is true, GtkButton allocates larger size than requested *
+ * and causes the panel image to grow indefinitely.                       *
+ * This workaround compensates for this difference.                       *
+ * Details in https://bugzilla.gnome.org/show_bug.cgi?id=698030           *
+ */
+static gint
+xfce_panel_image_padding_correction (GtkWidget *widget)
+{
+  GtkWidget             *parent;
+  GtkStyleContext       *context;
+  gint                   focus_width;
+  gint                   focus_pad;
+  gint                   correction;
+
+  parent = gtk_widget_get_parent (widget);
+  if (parent != NULL &&
+      GTK_IS_BUTTON (parent) &&
+      !gtk_widget_get_can_focus (parent))
+    {
+      context = gtk_widget_get_style_context (parent);
+      gtk_style_context_get_style (context,
+                                   "focus-line-width", &focus_width,
+                                   "focus-padding", &focus_pad,
+                                   NULL);
+      correction = (focus_width + focus_pad) * 2;
+    }
+  else
+    {
+      correction = 0;
+    }
+
+  return correction;
+}
+#endif
+
+
+#if GTK_CHECK_VERSION (3, 0, 0)
+static void
+xfce_panel_image_get_preferred_width (GtkWidget *widget,
+                                      gint      *minimum_width,
+                                      gint      *natural_width)
+{
+  XfcePanelImagePrivate *priv = XFCE_PANEL_IMAGE (widget)->priv;
+  GtkAllocation          alloc;
+  gint                   width, width_min;
+
+  if (priv->size > 0)
+    width = priv->size;
+  else if (priv->pixbuf != NULL)
+    width = gdk_pixbuf_get_width (priv->pixbuf);
+  else
+    {
+      gtk_widget_get_allocation (widget, &alloc);
+      width = alloc.width;
+    }
+
+#ifdef GTK_BUTTON_SIZING_FIX
+  width -= xfce_panel_image_padding_correction (widget);
+  width = MAX (width, 0);
+#endif
+
+  if (priv->size > 0)
+    width_min = width;
+  else
+    width_min = 0;
+
+  if (minimum_width != NULL)
+    *minimum_width = width_min;
+
+  if (natural_width != NULL)
+    *natural_width = width;
+}
+
+
+
+static void
+xfce_panel_image_get_preferred_height (GtkWidget *widget,
+                                       gint      *minimum_height,
+                                       gint      *natural_height)
+{
+  XfcePanelImagePrivate *priv = XFCE_PANEL_IMAGE (widget)->priv;
+  GtkAllocation          alloc;
+  gint                   height, height_min;
+
+  if (priv->size > 0)
+    height = height_min = priv->size;
+  else if (priv->pixbuf != NULL)
+    height = gdk_pixbuf_get_height (priv->pixbuf);
+  else
+    {
+      gtk_widget_get_allocation (widget, &alloc);
+      height = alloc.height;
+    }
+
+#ifdef GTK_BUTTON_SIZING_FIX
+  height -= xfce_panel_image_padding_correction (widget);
+  height = MAX (height, 0);
+#endif
+
+  if (priv->size > 0)
+    height_min = height;
+  else
+    height_min = 0;
+
+  if (minimum_height != NULL)
+    *minimum_height = height_min;
+
+  if (natural_height != NULL)
+    *natural_height = height;
+}
+#endif
+
+
+
+#if !GTK_CHECK_VERSION (3, 0, 0)
 static void
 xfce_panel_image_size_request (GtkWidget      *widget,
                                GtkRequisition *requisition)
@@ -302,6 +451,7 @@ xfce_panel_image_size_request (GtkWidget      *widget,
       requisition->height = widget->allocation.height;
     }
 }
+#endif
 
 
 
@@ -311,8 +461,7 @@ xfce_panel_image_size_allocate (GtkWidget     *widget,
 {
   XfcePanelImagePrivate *priv = XFCE_PANEL_IMAGE (widget)->priv;
 
-
-  widget->allocation = *allocation;
+  gtk_widget_set_allocation (widget, allocation);
 
   /* check if the available size changed */
   if ((priv->pixbuf != NULL || priv->source != NULL)
@@ -331,8 +480,8 @@ xfce_panel_image_size_allocate (GtkWidget     *widget,
       if (priv->pixbuf == NULL)
         {
           /* delay icon loading */
-          priv->idle_load_id = g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, xfce_panel_image_load,
-                                                widget, xfce_panel_image_load_destroy);
+          priv->idle_load_id = gdk_threads_add_idle_full (G_PRIORITY_DEFAULT_IDLE, xfce_panel_image_load,
+                                                          widget, xfce_panel_image_load_destroy);
         }
       else
         {
@@ -344,6 +493,56 @@ xfce_panel_image_size_allocate (GtkWidget     *widget,
 
 
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+static gboolean
+xfce_panel_image_draw (GtkWidget *widget,
+                       cairo_t   *cr)
+{
+  XfcePanelImagePrivate *priv = XFCE_PANEL_IMAGE (widget)->priv;
+  gint                   source_width, source_height;
+  gint                   dest_x, dest_y;
+  GtkIconSource         *source;
+  GdkPixbuf             *rendered = NULL;
+  GdkPixbuf             *pixbuf = priv->cache;
+  GtkStyleContext       *context;
+
+  if (G_LIKELY (pixbuf != NULL))
+    {
+      /* get the size of the cache pixbuf */
+      source_width = gdk_pixbuf_get_width (pixbuf);
+      source_height = gdk_pixbuf_get_height (pixbuf);
+
+      /* position */
+      dest_x = (priv->width - source_width) / 2;
+      dest_y = (priv->height - source_height) / 2;
+
+      context = gtk_widget_get_style_context (widget);
+
+      if (!gtk_widget_is_sensitive (widget))
+        {
+          source = gtk_icon_source_new ();
+          gtk_icon_source_set_pixbuf (source, pixbuf);
+          rendered = gtk_render_icon_pixbuf (context, source, -1);
+          gtk_icon_source_free (source);
+
+          if (G_LIKELY (rendered != NULL))
+            pixbuf = rendered;
+        }
+
+      /* draw the icon */
+      gtk_render_icon (context, cr, pixbuf, dest_x, dest_y);
+
+      if (rendered != NULL)
+        g_object_unref (G_OBJECT (rendered));
+    }
+
+  return FALSE;
+}
+#endif
+
+
+
+#if !GTK_CHECK_VERSION (3, 0, 0)
 static gboolean
 xfce_panel_image_expose_event (GtkWidget      *widget,
                                GdkEventExpose *event)
@@ -397,9 +596,47 @@ xfce_panel_image_expose_event (GtkWidget      *widget,
 
   return FALSE;
 }
+#endif
 
 
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+static void
+xfce_panel_image_style_updated (GtkWidget *widget)
+{
+  XfcePanelImagePrivate *priv = XFCE_PANEL_IMAGE (widget)->priv;
+  gboolean               force;
+
+  /* let gtk update the widget style */
+  (*GTK_WIDGET_CLASS (xfce_panel_image_parent_class)->style_updated) (widget);
+
+  /* get style property */
+  gtk_widget_style_get (widget, "force-gtk-icon-sizes", &force, NULL);
+
+  /* update if needed */
+  if (priv->force_icon_sizes != force)
+    {
+      priv->force_icon_sizes = force;
+      if (priv->size > 0)
+        gtk_widget_queue_resize (widget);
+    }
+
+  /* update the icon if we have an icon-name source */
+  /* and size is not set */
+  if (priv->source != NULL
+      && !g_path_is_absolute (priv->source)
+      && priv->size <= 0)
+    {
+      /* unset the size to force an update */
+      priv->width = priv->height = -1;
+      gtk_widget_queue_resize (widget);
+    }
+}
+#endif
+
+
+
+#if !GTK_CHECK_VERSION (3, 0, 0)
 static void
 xfce_panel_image_style_set (GtkWidget *widget,
                             GtkStyle  *previous_style)
@@ -430,6 +667,7 @@ xfce_panel_image_style_set (GtkWidget *widget,
       gtk_widget_queue_resize (widget);
     }
 }
+#endif
 
 
 
@@ -442,8 +680,6 @@ xfce_panel_image_load (gpointer data)
   GtkIconTheme          *icon_theme = NULL;
   gint                   dest_w, dest_h;
 
-  GDK_THREADS_ENTER ();
-
   dest_w = priv->width;
   dest_h = priv->height;
 
@@ -487,8 +723,6 @@ xfce_panel_image_load (gpointer data)
   if (G_LIKELY (priv->cache != NULL))
     gtk_widget_queue_draw (GTK_WIDGET (data));
 
-  GDK_THREADS_LEAVE ();
-
   return FALSE;
 }
 
@@ -507,8 +741,7 @@ xfce_panel_image_scale_pixbuf (GdkPixbuf *source,
                                gint       dest_width,
                                gint       dest_height)
 {
-  gdouble wratio;
-  gdouble hratio;
+  gdouble ratio;
   gint    source_width;
   gint    source_height;
 
@@ -526,13 +759,12 @@ xfce_panel_image_scale_pixbuf (GdkPixbuf *source,
     return g_object_ref (G_OBJECT (source));
 
   /* calculate the new dimensions */
-  wratio = (gdouble) source_width  / (gdouble) dest_width;
-  hratio = (gdouble) source_height / (gdouble) dest_height;
 
-  if (hratio > wratio)
-    dest_width  = rint (source_width / hratio);
-  else
-    dest_height = rint (source_height / wratio);
+  ratio = MIN ((gdouble) dest_width / (gdouble) source_width,
+               (gdouble) dest_height / (gdouble) source_height);
+
+  dest_width  = rint (source_width * ratio);
+  dest_height = rint (source_height * ratio);
 
   return gdk_pixbuf_scale_simple (source, MAX (dest_width, 1),
                                   MAX (dest_height, 1),
