@@ -125,6 +125,15 @@ migrate_config_action_48 (gpointer key,
       || g_strcmp0 (g_value_get_string (gvalue), "actions") != 0)
     return;
 
+  /* this is a bug that affects pre users: don't try to migrate
+   * when the appearance property is already set */
+  g_snprintf (str, sizeof (str), "%s/appearance", prop);
+  if (xfconf_channel_has_property (channel, str))
+    return;
+
+  /* set appearance to button mode */
+  xfconf_channel_set_uint (channel, str, 0);
+
   /* read and remove the old properties */
   g_snprintf (str, sizeof (str), "%s/first-action", prop);
   first_action_int = xfconf_channel_get_uint (channel, str, 0) + 1;
@@ -140,10 +149,6 @@ migrate_config_action_48 (gpointer key,
   if (first_action_int == second_action_int)
     second_action_int = 0;
 
-  /* set appearance to button mode */
-  g_snprintf (str, sizeof (str), "%s/appearance", prop);
-  xfconf_channel_set_uint (channel, str, 0);
-
   /* set orientation */
   g_snprintf (str, sizeof (str), "%s/invert-orientation", prop);
   xfconf_channel_set_bool (channel, str, second_action_int > 0);
@@ -155,8 +160,8 @@ migrate_config_action_48 (gpointer key,
   /* set the visible properties */
   g_snprintf (str, sizeof (str), "%s/items", prop);
   xfconf_channel_set_array (channel, str,
-                            G_TYPE_STRING, &first_action,
-                            G_TYPE_STRING, &second_action,
+                            G_TYPE_STRING, first_action,
+                            G_TYPE_STRING, second_action,
                             G_TYPE_INVALID);
 }
 
