@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2009 Nick Schermer <nick@xfce.org>
+ * Copyright (C) 2008-2010 Nick Schermer <nick@xfce.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 #include <gdk/gdk.h>
 
 gboolean  panel_dbus_client_display_preferences_dialog (guint         active,
+                                                        const gchar  *socket_id,
                                                         GError      **error);
 
 gboolean  panel_dbus_client_display_items_dialog       (guint         active,
@@ -35,6 +36,7 @@ gboolean  panel_dbus_client_add_new_item               (const gchar  *plugin_nam
                                                         GError      **error);
 
 gboolean  panel_dbus_client_plugin_event               (const gchar  *plugin_event,
+                                                        gboolean     *return_succeed,
                                                         GError      **error);
 
 gboolean  panel_dbus_client_terminate                  (gboolean      restart,
